@@ -1,4 +1,3 @@
-from epydemic import DrawSet
 import random
 import networkx as nx
 from logging import Logger
@@ -14,7 +13,7 @@ from gcmpy.tools.markov_chain_monte_carlo import MarkovChainMonteCarlo
 from gcmpy.tools.joint_excess_joint_degree_keys_view import (
     JointExcessJointDegreeKeysView,
 )
-
+from gcmpy.tools.draw_set import DrawSet
 
 class ErrorMarkovChainMonteCarloRewiring(Exception):
     ...
@@ -226,7 +225,7 @@ class MarkovChainMonteCarloRewiring(MarkovChainMonteCarlo):
         p._new_edge = (u0, v1)
         self._proposal_edges.append(p)
 
-    @MarkovChainMonteCarlo.proposal_efficiency
+    #@MarkovChainMonteCarlo.proposal_efficiency
     def swap_condition(
         self, G: nx.Graph, e0s: list, e1s: list, u0: int, v0: int
     ) -> bool:
@@ -363,9 +362,12 @@ class MarkovChainMonteCarloRewiring(MarkovChainMonteCarlo):
         convergence_count: int = 0
         while convergence_count <= self._convergence_limit:
 
+            self._proposal_count += 1
             if convergence_count % 50 == 0 and self._proposal_count != 0:
                 self._acceptance_ratio.append(
-                    float(self._proposals_accepted) / float(self._proposal_count)
+                    (
+                        self._proposal_count, float(convergence_count) / float(self._proposal_count)
+                    )
                 )
 
             # pick an edge at random.
@@ -407,6 +409,9 @@ class MarkovChainMonteCarloRewiring(MarkovChainMonteCarlo):
 
                 convergence_count += 1
 
+                if convergence_count % 1000 == 0:
+                    print(convergence_count)
+
                 # add the new proposal edges for both sides
                 for pe in self._proposal_edges:
                     e: tuple = pe._new_edge
